#
# spec file for package python-pyssim
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global skip_python36 1
Name:           python-pyssim
Version:        0.6
Release:        1.7
Summary:        Structured Similarity Image Metric (SSIM)
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jterrace/pyssim
Source:         https://files.pythonhosted.org/packages/source/p/pyssim/pyssim-%{version}.tar.gz
Patch0:         Pillow-imports.patch
# PATCH-FIX-UPSTREAM https://github.com/jterrace/pyssim/commit/db4296c12ca9c027eb9cd61b52195a78dfcc6711 Replace Image.ANTIALIAS with Image.LANCZOS
Patch1:         pillow10.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow
Requires:       python-numpy
Requires:       python-scipy
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module scipy}
# /SECTION
%python_subpackages

%description
Module for computing Structured Similarity Image Metric (SSIM) in Python.

%prep
%autosetup -p1 -n pyssim-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pyssim
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand # Tests extracted from .travis.yml
$python -m ssim test-images/test1-1.png test-images/test1-1.png | grep 1
$python -m ssim test-images/test1-1.png test-images/test1-2.png | grep 0.998
$python -m ssim test-images/test1-1.png "test-images/*" | grep -E " 1| 0.998| 0.672| 0.648" | wc -l | grep 4
$python -m ssim --cw --width 128 --height 128 test-images/test1-1.png test-images/test1-1.png | grep 1
$python -m ssim --cw --width 128 --height 128 test-images/test3-orig.jpg test-images/test3-rot.jpg | grep 0.938
}

%post
%python_install_alternative pyssim

%postun
%python_uninstall_alternative pyssim

%files %{python_files}
%license LICENSE.md
%doc README.md
%python_alternative %{_bindir}/pyssim
%{python_sitelib}/ssim
%{python_sitelib}/pyssim-%{version}*-info

%changelog
* Thu Oct  5 2023 Markéta Machová <mmachova@suse.com>
- Update to 0.6
  * support numpy 1.20
- Drop upstreamed numpy120.patch
- add upstream pillow10.patch
* Mon Mar  6 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add numpy120.patch to support numpy 1.20 gh#jterrace/pyssim#44
- Update to 0.5
  * No release notes found
* Sat Feb 13 2021 Dirk Müller <dmueller@suse.com>
- skip python 36 build (scipy)
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Feb 21 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github tarball until upstream includes the license
  and the tests, the master test refetching causes source validator
  to fail
* Thu Feb 21 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.4, with Pillow-imports.patch to workaround
  problems caused by top level Image.py
